@@ -28,7 +28,7 @@ import asyncio
 from typing import (
     TypeVar,
     Union,
-    Awaitable,
+    Coroutine,
     Callable,
     NewType,
     ClassVar,
@@ -45,7 +45,7 @@ from enum import Enum, auto
 from datetime import datetime
 from time import mktime
 from aiohttp import ClientSession
-from requests import delete, post, get, patch
+from requests import delete, post, get
 import colorama
 
 
@@ -74,8 +74,9 @@ __all__: tuple = (
     "DisFlags",
     "Snowflake",
     "ChannelId",
+    "ThreadId",
     "UserId",
-    "GuildlId",
+    "GuildId",
     # Private clients
     "Rest",
     "Flow",
@@ -447,8 +448,9 @@ class Snowflake(Generic[T]):
 
 
 ChannelId = NewType("ChannelId", int)
+ThreadId = NewType("ThreadId", int)
 UserId = NewType("UserId", int)
-GuildlId = NewType("GuildId", int)
+GuildId = NewType("GuildId", int)
 
 
 @final
@@ -706,7 +708,7 @@ class Flow:
                     if self._debug:
                         print(_DebugLoggingAwaiting(event.type, "register"))
 
-                    await self.ons["register2"]()
+                    await self.ons["register2"](event.data)
 
                     if self._debug:
                         print(_DebugLoggingAwaiting(event.type, "on_register2"))
@@ -895,6 +897,8 @@ class Flow:
                             print(_DebugLoggingAwaiting(event.type, "on_dm_typing"))
             except TypeError:
                 pass
+            except KeyError:
+                pass
 
             await asyncio.sleep(0.5)
 
@@ -910,7 +914,7 @@ class DisApi(_RequestsUserClass):
     """DisApi
     Class for init Rest and Flow event and edit they
     """
-    def __init__(self, token: str, intents, application_id):
+    def __init__(self, token: str, intents):
         """
         Init Class
 
@@ -927,7 +931,6 @@ class DisApi(_RequestsUserClass):
         self._on_ready = None
         self._on_messagec = None
         self.token = token
-        self.application_id = application_id
 
         self.flow = Flow(10, self.token, intents)
         self._r = Rest(self.token)
@@ -936,6 +939,7 @@ class DisApi(_RequestsUserClass):
         self.raw_app_commands = []
 
         self.user = None
+        self._debug = False
 
         self.app_commands.append({})  # Slash Commands
         self.app_commands.append({})  # User Commands
@@ -976,41 +980,66 @@ class DisApi(_RequestsUserClass):
         ons["components"] = self._on_components
         ons["modalsumbit"] = self._on_modal_sumbit
 
-        _url = f"{_mainurl()}applications/{self.application_id}/commands"
-
-        _raws = get(_url, headers=self._headers).json()
-
-        for raw in _raws:
-            for j in self.app_commands_jsons:
-                if raw["name"] == j["name"] and raw["type"] == j["type"]:
-                    _res = raw
-
-                    try:
-                        _res["description"] = j["description"]
-                    except KeyError:
-                        pass
-
-                    try:
-                        _res["options"] = j["options"]
-                    except KeyError:
-                        pass
-
-                    patch(f"{_url}/{raw['id']}", json=j, headers=self._headers)
-                else:
-                    delete(f"{_url}/{raw['id']}", headers=self._headers)
-                    post(url=_url, json=j, headers=self._headers)
+        self._debug = debug
 
         await self.flow.run(ons, status, debug, act)
 
-    async def _register2(self):
+    async def _register2(self, data: dict):
         # pass
         self.user: DisUser = self.get_user(self.flow.user_id)
 
+        if self._debug:
+            print(f"{colorama.Fore.YELLOW}Registering application commands...{colorama.Fore.RESET}")
+
+        app_id = data["application"]["id"]
+
+        _url = f"{_mainurl()}applications/{app_id}/commands"
+
+        application_commands_from_server = get(_url, headers=self._headers).json()
+        application_commands_from_code = self.app_commands_jsons
+
+        if not application_commands_from_server and not application_commands_from_code:
+            pass
+
+        elif not application_commands_from_server and application_commands_from_code:
+            for code in application_commands_from_code:
+                post_event = post(_url, json=code, headers=self._headers).json()
+
+                if self._debug:
+                    print(f"{colorama.Fore.BLUE}POST |{colorama.Fore.RESET} {post_event}")
+
+        elif not application_commands_from_code and application_commands_from_server:
+            for server in application_commands_from_server:
+                delete(f"{_url}/{server['id']}", headers=self._headers)
+
+                if self._debug:
+                    print(f"{colorama.Fore.CYAN}DELETE |{colorama.Fore.RESET} {server}")
+        elif application_commands_from_code and application_commands_from_server:
+            for server in application_commands_from_server:
+                delete(f"{_url}/{server['id']}", headers=self._headers)
+
+                if self._debug:
+                    print(f"{colorama.Fore.CYAN}DELETE |{colorama.Fore.RESET} {server}")
+
+            for code in application_commands_from_code:
+                post_event = post(_url, json=code, headers=self._headers).json()
+
+                if self._debug:
+                    print(f"{colorama.Fore.BLUE}POST |{colorama.Fore.RESET} {post_event}")
+
+        if self._debug:
+            server_app_commands = get(_url, headers=self._headers).json()
+
+            print(f"{colorama.Fore.YELLOW}Current commands on server: {colorama.Fore.RESET}",
+                  end="")
+            print(server_app_commands)
+            print(f"{colorama.Fore.GREEN}Regsiter is completed!")
+
     async def _on_interaction(self, token, interaction_id, command_name, bot_token: str,
                               interaction_type, data: JsonOutput, type_of_command=None) -> NoReturn:
-        if interaction_type == 2:
-            _ctx = Context(token, interaction_id, bot_token)
+        interaction_info = (token, interaction_id)
 
+        if interaction_type == 2:
             try:
                 if type_of_command == 3:  # Message Commands
                     resolved: dict = data["data"]["resolved"]["messages"]
@@ -1023,8 +1052,18 @@ class DisApi(_RequestsUserClass):
                     except KeyError:
                         _m_d.setdefault("id", _m_id)
 
-                    _m = DisMessage(_m_d, self.token)
+                    _c_id = _m_d["channel_id"]
 
+                    _c_d = get(f"{_mainurl()}channels/{str(_c_id)}")
+
+                    _m = None
+
+                    if _c_d["type"] == 1:
+                        _m = DisMessage(_m_d, self.token)
+                    else:
+                        _m = DmMessage(_m_d, self.token)
+
+                    _ctx = Context(interaction_info, bot_token)
                     await self.app_commands[type_of_command - 1][command_name](_ctx, _m)
 
                 elif type_of_command == 2:  # User Commands
@@ -1040,6 +1079,7 @@ class DisApi(_RequestsUserClass):
 
                     _u = DisUser(_u_d, self.token)
 
+                    _ctx = Context(interaction_info, bot_token)
                     await self.app_commands[type_of_command - 1][command_name](_ctx, _u)
 
                 elif type_of_command == 1:  # Slash Commands
@@ -1055,7 +1095,9 @@ class DisApi(_RequestsUserClass):
 
                     func = self.app_commands[type_of_command - 1][command_name]
 
-                    await func(_ctx, OptionArgs(_args))
+                    _ctx = Context(interaction_info, bot_token, OptionArgs(_args))
+
+                    await func(_ctx)
                 else:
                     pass
             except KeyError:
@@ -1125,7 +1167,7 @@ class DisApi(_RequestsUserClass):
 
         return self._r.get("channel", channel_id)
 
-    def get_guild(self, guild_id: GuildlId) -> DisGuild:
+    def get_guild(self, guild_id: GuildId) -> DisGuild:
         """
         Get guild by id
 
@@ -1136,7 +1178,7 @@ class DisApi(_RequestsUserClass):
 
         return DisGuild(guild_id, self)
 
-    def get_guild_json(self, guild_id: GuildlId) -> JsonOutput:
+    def get_guild_json(self, guild_id: GuildId) -> JsonOutput:
         """
         Get guild by id (Json Output)
 
@@ -1148,7 +1190,7 @@ class DisApi(_RequestsUserClass):
 
         return self._r.get("guild", guild_id)
 
-    def create_command(self, payload: dict, func: Awaitable):
+    def create_command(self, payload: dict, func: Callable[..., Coroutine[Any, Any, Any]]):
         """create_command
         Create application command
 
@@ -1156,8 +1198,6 @@ class DisApi(_RequestsUserClass):
             payload (dict): Json data of command
             func (Awaitable): Function for awaiting command
         """
-        _url = f"https://discord.com/api/v10/applications/{self.application_id}/commands"
-
         def app_func_register(number):
             self.app_commands[number][payload["name"]] = func
 
